# flux-framework fluxoperator

Python SDK for Flux-Operator

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1alpha1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

See the [docs](docs) for more details!
